==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/test/java/internal/junit/wizard/RunJavaWizard.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.java.internal.junit.wizard;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IResourceStatus;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.OperationCanceledException;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IWorkbenchPage;

import org.eclipse.hyades.execution.harness.TestExecutionHarness;
import org.eclipse.hyades.models.common.configuration.CFGMachine;
import org.eclipse.hyades.models.common.facades.behavioral.ITest;
import org.eclipse.hyades.models.common.facades.behavioral.ITestCase;
import org.eclipse.hyades.models.common.facades.behavioral.ITestSuite;
import org.eclipse.hyades.test.common.internal.wizard.RunWizard;
import org.eclipse.hyades.test.java.TestJavaPlugin;
import org.eclipse.hyades.test.ui.TestUI;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.internal.navigator.ExecutionNavigator;
import org.eclipse.hyades.ui.internal.util.StringUtil;

public class RunJavaWizard extends RunWizard implements IRunnableWithProgress
{
	private String error;
	private String executionResultLocation;
	private String executionResultName;
	boolean runWizard;

	public RunJavaWizard()
	{
		super();
	}

	public boolean doPerformFinish()
	{
		error = null;
		runWizard = true;

		// Get the location for the execution result		
		executionResultLocation = getContainerPath().toString();
		executionResultName = getExecutionResultName();

		try
		{
			// run operation in separate thread and make it canceable
			new ProgressMonitorDialog(getShell()).run(true, true, this);
		}
		catch (InvocationTargetException e)
		{
			runWizard = false;
			MessageDialog.openError(getShell(), TestJavaPlugin.getString("W_ERROR"), e.getTargetException().getMessage());
			return false;
		}
		catch (InterruptedException e)
		{
			runWizard = false;
			return false;
		}

		runWizard = false;
		if (error != null)
		{
			if (!error.equals(""))
			{
				String errMsg = TestJavaPlugin.getString("CONNECTION_FAIL_TEXT");
				errMsg = StringUtil.replace(errMsg, "%1", getLocation().getName());

				Status err1 = new Status(IStatus.WARNING, ResourcesPlugin.PI_RESOURCES, IResourceStatus.INTERNAL_ERROR, error, null);

				ErrorDialog.openError(getShell(), TestJavaPlugin.getString("TEST_ERR_MSG"), errMsg, err1);
			}

			return false;
		}

		IWorkbenchPage page = TestJavaPlugin.getInstance().getWorkbench().getActiveWorkbenchWindow().getActivePage();
		if (page != null)
		{
			try
			{
				page.showView(ExecutionNavigator.ID);
			}
			catch (Exception exc)
			{
				TestUIPlugin.logError(exc);
			}

		}

		return true;
	}

	public void run(IProgressMonitor mon)
	{
		runWizard = true;
		(new RefreshUI(mon)).start();

		ITestSuite testSuite = null;
		if (getTest() instanceof ITestSuite)
			testSuite = (ITestSuite)getTest();
		else if(getTest() instanceof ITestCase)
			testSuite = ((ITestCase)getTest()).getOwner();

		String machineName = null;
		if(getLocation() instanceof CFGMachine)
			machineName = ((CFGMachine)getLocation()).getHostName();
		else
			machineName = getLocation().getName();
			
		String port = TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.LOCALHOST_PORT);

		error = new TestExecutionHarness().launchTest((ITestSuite)testSuite, (ITest)getTest(), machineName, port, executionResultLocation, executionResultName, false, false);

		mon.done();
	}

	class RefreshUI extends Thread
	{
		IProgressMonitor monitor;

		public RefreshUI(IProgressMonitor mon)
		{
			super("run_test");
			monitor = mon;
		}

		public void run()
		{
			while (runWizard)
			{
				try
				{
					Display d = Display.getDefault();
					d.asyncExec(new Runnable()
					{
						public void run()
						{

							if (monitor.isCanceled())
							{
								if (monitor.isCanceled())
								{
									runWizard = false;
									throw new OperationCanceledException();
								}
							}

						}
					});

					sleep(2000);
				}
				catch (InterruptedException exc)
				{
				}
			}
		}
	}
}

==> hyades.source_1.2.0_20040115_0724.zip: org/eclipse/hyades/test/java/internal/junit/wizard/RunJavaWizard.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.java.internal.junit.wizard;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IResourceStatus;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.OperationCanceledException;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IWorkbenchPage;

import org.eclipse.hyades.execution.harness.TestExecutionHarness;
import org.eclipse.hyades.models.common.configuration.CFGMachine;
import org.eclipse.hyades.models.common.facades.behavioral.ITest;
import org.eclipse.hyades.models.common.facades.behavioral.ITestCase;
import org.eclipse.hyades.models.common.facades.behavioral.ITestSuite;
import org.eclipse.hyades.test.common.internal.wizard.RunWizard;
import org.eclipse.hyades.test.java.TestJavaPlugin;
import org.eclipse.hyades.test.ui.TestUI;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.internal.navigator.ExecutionNavigator;
import org.eclipse.hyades.ui.internal.util.StringUtil;

public class RunJavaWizard extends RunWizard implements IRunnableWithProgress
{
	private String error;
	private String executionResultLocation;
	private String executionResultName;
	boolean runWizard;

	public RunJavaWizard()
	{
		super();
	}

	public boolean doPerformFinish()
	{
		error = null;
		runWizard = true;

		// Get the location for the execution result		
		executionResultLocation = getContainerPath().toString();
		executionResultName = getExecutionResultName();

		try
		{
			// run operation in separate thread and make it canceable
			new ProgressMonitorDialog(getShell()).run(true, true, this);
		}
		catch (InvocationTargetException e)
		{
			runWizard = false;
			MessageDialog.openError(getShell(), TestJavaPlugin.getString("W_ERROR"), e.getTargetException().getMessage());
			return false;
		}
		catch (InterruptedException e)
		{
			runWizard = false;
			return false;
		}

		runWizard = false;
		if (error != null)
		{
			if (!error.equals(""))
			{
				String errMsg = TestJavaPlugin.getString("CONNECTION_FAIL_TEXT");
				errMsg = StringUtil.replace(errMsg, "%1", getLocation().getName());

				Status err1 = new Status(IStatus.WARNING, ResourcesPlugin.PI_RESOURCES, IResourceStatus.INTERNAL_ERROR, error, null);

				ErrorDialog.openError(getShell(), TestJavaPlugin.getString("TEST_ERR_MSG"), errMsg, err1);
			}

			return false;
		}

		IWorkbenchPage page = TestJavaPlugin.getInstance().getWorkbench().getActiveWorkbenchWindow().getActivePage();
		if (page != null)
		{
			try
			{
				page.showView(ExecutionNavigator.ID);
			}
			catch (Exception exc)
			{
				TestUIPlugin.logError(exc);
			}

		}

		return true;
	}

	public void run(IProgressMonitor mon)
	{
		runWizard = true;
		(new RefreshUI(mon)).start();

		ITestSuite testSuite = null;
		if (getTest() instanceof ITestSuite)
			testSuite = (ITestSuite)getTest();
		else if(getTest() instanceof ITestCase)
			testSuite = ((ITestCase)getTest()).getOwner();

		String machineName = null;
		if(getLocation() instanceof CFGMachine)
			machineName = ((CFGMachine)getLocation()).getHostName();
		else
			machineName = getLocation().getName();
			
		String port = TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.LOCALHOST_PORT);

		error = new TestExecutionHarness().launchTest((ITestSuite)testSuite, (ITest)getTest(), getLocation(), port, executionResultLocation, executionResultName, false, false);

		mon.done();
	}

	class RefreshUI extends Thread
	{
		IProgressMonitor monitor;

		public RefreshUI(IProgressMonitor mon)
		{
			super("run_test");
			monitor = mon;
		}

		public void run()
		{
			while (runWizard)
			{
				try
				{
					Display d = Display.getDefault();
					d.asyncExec(new Runnable()
					{
						public void run()
						{

							if (monitor.isCanceled())
							{
								if (monitor.isCanceled())
								{
									runWizard = false;
									throw new OperationCanceledException();
								}
							}

						}
					});

					sleep(2000);
				}
				catch (InterruptedException exc)
				{
				}
			}
		}
	}
}
